Crate cs_epic_wallet_impls

Concrete implementations of types found in libwallet, organised this way mostly to avoid any circular dependencies of any kind Functions in this crate should not use the wallet api crate directly

Modules

epicbox
test_framework
tor

Structs

Container
DefaultLCProvider
DefaultWalletImpl
Main wallet instance
EmojiSlate
EpicboxBroker
TODO: reduce to broker
EpicboxChannel
EpicboxController
EpicboxListenChannel
EpicboxListener
EpicboxPublisher
EpicboxSubscriber
HTTPNodeClient
HttpSlateSender
KeybaseAllChannels
Receives slates on all channels with topic SLATE_NEW
KeybaseChannel
LMDBBackend
PathToSlate

Enums

Error
Wallet errors, mostly wrappers around underlying crypto or I/O errors.
ListenerInterface

Traits

Listener
SlateGetter
Checks for a transaction from a corresponding SlatePutter, returns the transaction if it exists
SlatePutter
Posts slates to be read later by a corresponding getter
SlateReceiver
SlateSender
Sends transactions to a corresponding SlateReceiver

Functions

create_sender
select a SlateSender based on method and dest fields from, e.g., SendArgs
wallet_db_exists
test to see if database files exist in the current directory. If so, use a DB backend for all operations