Concrete implementations of types found in libwallet, organised this way mostly to avoid any circular dependencies of any kind Functions in this crate should not use the wallet api crate directly
Modules
Structs
- Container
- DefaultLC
Provider - Default
Wallet Impl - Main wallet instance
- Emoji
Slate - Epicbox
Broker - TODO: reduce to broker
- Epicbox
Channel - Epicbox
Controller - Epicbox
Listen Channel - Epicbox
Listener - Epicbox
Publisher - Epicbox
Subscriber - HTTP
Node Client - Http
Slate Sender - Keybase
AllChannels - Receives slates on all channels with topic SLATE_NEW
- Keybase
Channel - LMDB
Backend - Path
ToSlate
Enums
- Error
- Wallet errors, mostly wrappers around underlying crypto or I/O errors.
- Listener
Interface
Traits
- Listener
- Slate
Getter - Checks for a transaction from a corresponding SlatePutter, returns the transaction if it exists
- Slate
Putter - Posts slates to be read later by a corresponding getter
- Slate
Receiver - Slate
Sender - Sends transactions to a corresponding SlateReceiver
Functions
- create_
sender - select a SlateSender based on method and dest fields from, e.g., SendArgs
- wallet_
db_ exists - test to see if database files exist in the current directory. If so, use a DB backend for all operations